@@ -10,9 +10,6 @@ class ScpiTransportBase(IO):
     _transport_info: str = 'Unknown'
     _transport_type: str = 'Unknown'
 
-    _encoding: str = 'utf8'
-    _newline: str = '\r\n'
-
     _io: BinaryIO = None
     _logger: logging.Logger
 
@@ -60,15 +57,14 @@ class ScpiTransportBase(IO):
         self._logger.debug(f'write: block with size of {n} bytes')
         return n
 
-    def readline(self, size: int = -1) -> str:
-        data = self._io.readline(size)
-        self._logger.debug(f'read line {str(bytes(data))[1:]}')
-        return data.decode(self._encoding).rstrip(self._newline)
+    def readline(self, size: int = -1) -> bytes:
+        line = self._io.readline(size)
+        self._logger.debug(f'read line {str(bytes(line))[1:]}')
+        return line
 
-    def writeline(self, line: str) -> None:
-        data = (line + self._newline).encode(self._encoding)
-        self._logger.debug(f'write line {str(bytes(data))[1:]}')
-        self._io.writelines([data])
+    def writeline(self, line: bytes) -> None:
+        self._logger.debug(f'write line {str(bytes(line))[1:]}')
+        self._io.write(line)
         self._io.flush()
 
     def readlines(self, hint: int = ...) -> List[AnyStr]:
