@@ -281,7 +281,7 @@ class ScpiArbBlock(ScpiTypeBase):
 class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
     """
     Class representing IEEE488.2 Arbitrary block program data (7.7.6) and
-    definite length arbitrary block response (8.7.9)
+    in/definite length arbitrary block response (8.7.9/8.7.10)
 
         This element allows any 8 bit bytes to be transmitted in a message.
         This element is particularly helpful for sending large quantities of data.
@@ -289,13 +289,14 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
     Note that this class is derived from io.RawIOBase and can be used for stream processing
     """
 
-    def __init__(self, stream: BinaryIO, length: int, strip: bool = False) -> None:
+    def __init__(self, stream: BinaryIO, length: int, indefinite: bool = False) -> None:
         """Initialize object from a `ScpiTransportBase` object and length integer"""
         super().__init__()
         self._stream = stream
         self._length = length
         self._remaining = length
-        self._strip = strip
+        self._indefinite = indefinite
+        self._strip = True if not indefinite else False
 
     def __str__(self) -> str:
         return f'<stream with {self._length} bytes of binary data>'
@@ -331,8 +332,11 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
         raise NotImplementedError()
 
     def read(self, __size: int = -1) -> Optional[bytes]:
+        if self._indefinite and __size == -1:
+            raise ValueError('__size parameter must be present for indefinite arbitrary block')
+
         data = self._stream.read(__size)
-        self._remaining -= len(data)
+        if not self._indefinite: self._remaining -= len(data)
 
         if self._strip and (self._remaining == 0):
             # eat newline
@@ -362,12 +366,12 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
         num = int(head[1:2])
 
         if num == 0:
-            raise NotImplementedError("Indefinite length arbitrary block response not implemented")
+            # indefinite size arbitrary
+            return ScpiArbStream(transport, 0, indefinite=True)
 
-        # read header
+        # read header for definite size arbitrary block
         length = int(transport.read(num))
-
-        return ScpiArbStream(transport, length, strip=True)
+        return ScpiArbStream(transport, length)
 
 
 class ScpiBool(ScpiTypeBase):
